#!/bin/sh -ex

[ -r LICENSE.md ]
[ -e debian ] || ln -fs contrib/debian debian
[ -r debian/changelog ]
[ -d .git ]

branch=$(git rev-parse --abbrev-ref HEAD)

git checkout master

old_descr=$(git describe)

git fetch --all --tags
git pull --ff-only origin master

descr=$(git describe)

COMMIT_ID=$(git rev-parse HEAD)
export COMMIT_ID

git checkout "$branch"

if [ "$old_descr" = "$descr" ]; then
	if ! head -n 1 debian/changelog | fgrep " UNRELEASED;" >/dev/null; then
		set +x
		echo; echo "Nothing to do."; echo
		exit 0
	fi
fi

git merge master

date=$(date +%Y%m%d)
rev="01"
suffix="0ab1"

last_date=$(head -n 1 debian/changelog | cut -d'.' -f2 | cut -d'.' -f1)
last_rev=$(head -n 1 debian/changelog | cut -d'.' -f3 | cut -d'-' -f1)
last_suffix=$(head -n 1 debian/changelog | cut -d'-' -f2 | cut -d')' -f1)

if head -n 1 debian/changelog | fgrep " UNRELEASED;" >/dev/null; then
	if [ "$last_date" = "$date" ]; then
		rev=$last_rev
		suffix=$last_suffix
	fi
else
	if [ "$last_date" = "$date" ]; then
		rev=$(printf "%02d" $((last_rev+1)))
	fi
fi

version="0.$date.$rev-$suffix"

dch -v "$version" "Pulled upstream Git version $descr"
dch -r ""

git add contrib/debian/changelog
git commit -m "${branch} ${version}, upstream $descr"
git tag "${branch}_${version}"

dpkg-buildpackage -rfakeroot -b

